summaryrefslogtreecommitdiff
path: root/libiberty/splay-tree.c
diff options
context:
space:
mode:
authorMike Stump <mrs@apple.com>2002-09-12 00:51:25 +0000
committerMike Stump <mrs@gcc.gnu.org>2002-09-12 00:51:25 +0000
commit6eedb9ca7676c3b966237ec9f111e107370c7bc4 (patch)
tree8459439e603ba32f5af1b4e0f932d0d0fa3d5ab9 /libiberty/splay-tree.c
parent09bfbc1c1157e9dec90a9c826eab6d1d6306006b (diff)
* splay-tree.c (splay_tree_successor): Fix comments.
From-SVN: r57044
Diffstat (limited to 'libiberty/splay-tree.c')
-rw-r--r--libiberty/splay-tree.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libiberty/splay-tree.c b/libiberty/splay-tree.c
index 7999447bc11..3227ed3d3a6 100644
--- a/libiberty/splay-tree.c
+++ b/libiberty/splay-tree.c
@@ -482,7 +482,7 @@ splay_tree_predecessor (sp, key)
}
/* Return the immediate successor KEY, or NULL if there is no
- predecessor. KEY need not be present in the tree. */
+ successor. KEY need not be present in the tree. */
splay_tree_node
splay_tree_successor (sp, key)
@@ -492,7 +492,7 @@ splay_tree_successor (sp, key)
int comparison;
splay_tree_node node;
/* If the tree is empty, there is certainly no predecessor. */
if (!sp->root)
return NULL;
@@ -492,7 +492,7 @@ splay_tree_successor (sp, key)
int comparison;
splay_tree_node node;
- /* If the tree is empty, there is certainly no predecessor. */
+ /* If the tree is empty, there is certainly no successor. */
if (!sp->root)
return NULL;